package cn.com.qmth.examcloud.core.questions.api.provider;

import java.util.Map;

import io.swagger.annotations.ApiOperation;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import cn.com.qmth.examcloud.commons.base.exception.StatusException;
import cn.com.qmth.examcloud.core.questions.api.ExtractConfigCloudService;
import cn.com.qmth.examcloud.core.questions.api.request.GetPaperReq;
import cn.com.qmth.examcloud.core.questions.api.request.GetQuestionReq;
import cn.com.qmth.examcloud.core.questions.api.response.GetPaperResp;
import cn.com.qmth.examcloud.core.questions.api.response.GetQuestionResp;
import cn.com.qmth.examcloud.core.questions.service.ExtractConfigProviderService;
import cn.com.qmth.examcloud.question.core.paper.DefaultPaper;
import cn.com.qmth.examcloud.question.core.question.DefaultQuestion;

/**
 * @author 		weiwenhai
 * @date		2018.8.15
 * @company		qmth
 * @describle	调卷规则远程调用请求接口实现类
 * @code		010
 */
@Transactional
@RestController
@RequestMapping("${$rmp.cloud.questions}" + "extract_config")
public class ExtractConfigCloudServiceProvider implements ExtractConfigCloudService{

	private static final long serialVersionUID = 2346453260179681094L;
	
	@Autowired
	private ExtractConfigProviderService extractConfigExamService;

	@ApiOperation(value = "根据调卷规则抽取考试试卷")
	@PostMapping("getPaper")
	@Override
	public GetPaperResp getPaper(@RequestBody GetPaperReq paperReq) {
		Long examId = paperReq.getExamId();
		if (null == examId) {
			throw new StatusException("Q-010036", "examId is null");
		}
		String courseCode = paperReq.getCourseCode(); 
		if(StringUtils.isBlank(courseCode)){
			throw new StatusException("Q-010040", "courseCode is null");
		}
		String groupCode = paperReq.getGroupCode();
		if(StringUtils.isBlank(groupCode)){
			throw new StatusException("Q-010045", "groupCode is null");
		}
		Map<String, Object> map = extractConfigExamService.getDefaultPaper(paperReq.getExamId(),paperReq.getCourseCode(),paperReq.getGroupCode());
		GetPaperResp resp = new GetPaperResp();
		resp.setSortQptionOrder((Short)map.get("upSetOptionOrder") == 0 ? false:true);
		resp.setSortQuestionOrder((Short)map.get("upSetQuestionOrder") == 0 ? false:true);
		resp.setDefaultPaper((DefaultPaper)map.get("defaultPaper"));
		return resp;
	}

	@ApiOperation(value = "根据调卷规则抽取考试试卷")
	@PostMapping("getQuestion")
	@Override
	public GetQuestionResp getQuestion(@RequestBody GetQuestionReq questionReq) {
		Long examId = questionReq.getExamId();
		if (null == examId) {
			throw new StatusException("Q-010071", "examId is null");
		}
		String courseCode = questionReq.getCourseCode(); 
		if(StringUtils.isBlank(courseCode)){
			throw new StatusException("Q-010075", "courseCode is null");
		}
		String groupCode = questionReq.getGroupCode();
		if(StringUtils.isBlank(groupCode)){
			throw new StatusException("Q-010079", "groupCode is null");
		}
		String questionId = questionReq.getQuestionId();
		if(StringUtils.isBlank(questionId)){
			throw new StatusException("Q-010083", "questionId is null");
		}
		DefaultQuestion defaultQuestion = extractConfigExamService.getDefaultQuestion(examId, courseCode, groupCode, questionId);
		GetQuestionResp resp = new GetQuestionResp();
		resp.setDefaultQuestion(defaultQuestion);
		return resp;
	}
	
}
